==> debestia8.3-0.3b1pl2.zip: debestia8.3-0.3b1pl2/data/creaturescripts/scripts/think.lua <==
function onAdvance(cid, skillname, oldskill, newskill)
	if skillname == 8 then
	local newlevel = newskill
	local oldlevel = oldskill
		if newlevel == 2 or newlevel == 8 or newlevel == 10 or newlevel == 20 or newlevel == 30 or newlevel == 40 or newlevel == 50 then
			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			
			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			
			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)

			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			
			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
		end

		if newlevel == 2 then
			doPlayerSendTextMessage(cid, 22, "Od teraz mozesz uzywac czaru 'exura' do leczenia!")
		end

		if newlevel == 7 then
			if getPlayerVocation(cid) == 1 then
				doPlayerSendTextMessage(cid, 22, "Otrzymales prezent od sklepu magicznego 'Houdini', a takze zaproszenie do sklepu kiedy juz bedziesz w Kiobios w celu nabycia run i manafluidow.")
				doPlayerAddItem(cid,2190,1)
			elseif getPlayerVocation(cid) == 2 then
				doPlayerSendTextMessage(cid, 22, "Otrzymales prezent od Zielonych Druidow. Zapraszaja oni Ciebie do rozwoju w swojej szkole magii.")
				doPlayerAddItem(cid,2182,1)
			elseif getPlayerVocation(cid) == 3 then
				doPlayerSendTextMessage(cid, 22, "Otrzymales prezent od sklepu 'Dist Tactics'. Pallia zaprasza Ciebie do sklepu dla prawdziwych milosnikow walki z dystansu kiedy tylko bedziesz w Kiobios.")
				doPlayerAddItem(cid,2389,10)
			elseif getPlayerVocation(cid) == 4 then
				doPlayerSendTextMessage(cid, 22, "Otrzymales prezent od Krola Kiobios. Liczy on, ze kiedy rozwiniesz swoje umiejetnosci w walce mieczem staniesz sie jego wiernym rycerzem.")
				doPlayerAddItem(cid,2412,1)
			end
		end

		local oracleCords = {x=303, y=740, z=7} 
		if newlevel == 8 then
			doSendMagicEffect(getPlayerPosition(cid),10)
			doPlayerSetTown(cid,1)
			doTeleportThing(cid,oracleCords,0)
			doSendMagicEffect(oracleCords,10)
			doPlayerSendTextMessage(cid, 22, "Gratuluje! Osiagnales poziom na ktorym mozesz juz mieszkac w miescie Kiobios!")
		end

		if newlevel == 13 then
			if isSorcerer(cid) == TRUE then
			doPlayerSendTextMessage(cid, 22, "Magowie dostrzegli, ze bardzo dobrze rozwijasz sie w swojej profesji, aby ulatwic Ci dalszy rozwoj przekazali Ci nowa rozdzke.")
			doPlayerAddItem(cid,2191,1)
			elseif isDruid(cid) == TRUE then
			doPlayerSendTextMessage(cid, 22, "Druidzi przekazali Ci drobny prezent dzieki ktoremu lepiej bedziesz mogl wykorzystac swoja magiczna moc.")
			doPlayerAddItem(cid,2186,1)
			end
		end
		
			if newlevel == 100 then
			local ppos = getPlayerPosition(cid)
			local positions = {
				{x=ppos.x-3, y=ppos.y-1, z=ppos.z},
				{x=ppos.x-1, y=ppos.y-1, z=ppos.z},
				{x=ppos.x, y=ppos.y-1, z=ppos.z},
				{x=ppos.x+1, y=ppos.y-1, z=ppos.z},
				{x=ppos.x+3, y=ppos.y-1, z=ppos.z},
				{x=ppos.x+4, y=ppos.y-1, z=ppos.z},
				{x=ppos.x+5, y=ppos.y-1, z=ppos.z},
				
				{x=ppos.x-3, y=ppos.y, z=ppos.z},
				{x=ppos.x-1, y=ppos.y, z=ppos.z},
				{x=ppos.x+1, y=ppos.y, z=ppos.z},
				{x=ppos.x+3, y=ppos.y, z=ppos.z},
				{x=ppos.x+5, y=ppos.y, z=ppos.z},
				
				{x=ppos.x-3, y=ppos.y+1, z=ppos.z},
				{x=ppos.x-1, y=ppos.y+1, z=ppos.z},
				{x=ppos.x, y=ppos.y+1, z=ppos.z},
				{x=ppos.x+1, y=ppos.y+1, z=ppos.z},
				{x=ppos.x+3, y=ppos.y+1, z=ppos.z},
				{x=ppos.x+4, y=ppos.y+1, z=ppos.z},
				{x=ppos.x+5, y=ppos.y+1, z=ppos.z},
			}
			local effect = math.random(CONST_ME_FIREWORK_YELLOW,CONST_ME_FIREWORK_BLUE)
			for i = 1, table.getn(positions) do
				doSendMagicEffect(positions[i],effect)
			end
		end
	end
	return TRUE
end

function onAdvanceController(cid)
	local skillLevel = OLD_LEVELS[cid]
	local level = getPlayerLevel(cid)
	if skillLevel < level then
		onAdvance(cid, 8, skillLevel, level)
		OLD_LEVELS[cid] = level
	end
	return TRUE
end
function onThink(cid)
	local current_time = os.time()
	if getPlayerStorageValue(cid,STORAGEVALUE_NEXT_REGEN_CHECK) < current_time then
		if OLD_LEVELS[cid] == nil or mshield[cid] == nil then
			OLD_LEVELS[cid] = getPlayerLevel(cid)
			mshield[cid] = 0
		end
		setPlayerStorageValue(cid,STORAGEVALUE_NEXT_REGEN_CHECK, current_time)
		-- SALE TRENINGOWE
		if getPlayerStorageValue(cid, trainstoragevalue_room) > 0 then
			if getPlayerStorageValue(cid, trainstoragevalue_time) < os.time() then --kickowac
				local roomKickPoss = kick_position[getPlayerStorageValue(cid, trainstoragevalue_room)]
				local kickPos = roomKickPoss[math.random(1,6)]
				doTeleportThing(cid, kickPos, TRUE)
				doPlayerSendTextMessage(cid,19,'You were kicked from train room.')
			end
		end
		-- WIEZIENIE
		if getPlayerStorageValue(cid, jailedstoragevalue_bool) == 1 then
			if getPlayerStorageValue(cid, jailedstoragevalue_time) < os.time() then --unjail
				doTeleportThing(cid, unjailpos, TRUE)
				doPlayerSendTextMessage (cid, MESSAGE_INFO_DESCR, 'See you later.')
				setPlayerStorageValue(cid, jailedstoragevalue_time, 0)
				setPlayerStorageValue(cid, jailedstoragevalue_bool, 0)
			else -- czy w wiezieniu powinien byc
				local ppos = getCreaturePosition(cid)
				if ppos.x < jailfrompos.x or ppos.y < jailfrompos.y or ppos.x > jailtopos.x or ppos.y > jailtopos.y then
					doTeleportThing(cid, jailpos, TRUE)
					doPlayerSendTextMessage(cid, MESSAGE_INFO_DESCR, 'You are jailed until ' .. os.date("%H:%M:%S", getPlayerStorageValue(cid, jailedstoragevalue_time)) .. ' (now is: ' .. os.date("%H:%M:%S", os.time()) .. ').')
				end
			end
		end
		-- MANA SHIELD
		local con = math.ceil(getCreatureCondition(cid, CONDITION_MANASHIELD) / 1000)-3
		if con > 0 and con <= 10 and mshield[cid] ~= con then
			mshield[cid] = con
			doPlayerSendTextMessage(cid, MESSAGE_STATUS_CONSOLE_BLUE, con .. " second(s) of mana shield left.")
		end
		onAdvanceController(cid)
	end
 	return TRUE
end

==> debestia8.4-0.3.1pl2.zip: debestia8.4-0.3.1pl2/data/creaturescripts/scripts/think.lua <==
function onAdvance(cid, skillname, oldskill, newskill)
	if skillname == 8 then
	local newlevel = newskill
	local oldlevel = oldskill
		if newlevel == 2 or newlevel == 8 or newlevel == 10 or newlevel == 20 or newlevel == 30 or newlevel == 40 or newlevel == 50 then
			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 1000, param)
			
			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 2500, param)
			
			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 5000, param)

			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 7500, param)
			
			local param = {cid = cid, x = -1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 0, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 1, y = -1, typee = CONST_ME_FIREWORK_RED}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 0, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = -1, y = 0, typee = CONST_ME_FIREWORK_YELLOW}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = -1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 0, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
			local param = {cid = cid, x = 1, y = 1, typee = CONST_ME_GREEN_RINGS}
			local animid = addEvent(doShowEffectOnPosition, 10000, param)
		end

		if newlevel == 2 then
			doPlayerSendTextMessage(cid, 22, "Od teraz mozesz uzywac czaru 'exura' do leczenia!")
		end

		if newlevel == 7 then
			if getPlayerVocation(cid) == 1 then
				doPlayerSendTextMessage(cid, 22, "Otrzymales prezent od sklepu magicznego 'Houdini', a takze zaproszenie do sklepu kiedy juz bedziesz w Kiobios w celu nabycia run i manafluidow.")
				doPlayerAddItem(cid,2190,1)
			elseif getPlayerVocation(cid) == 2 then
				doPlayerSendTextMessage(cid, 22, "Otrzymales prezent od Zielonych Druidow. Zapraszaja oni Ciebie do rozwoju w swojej szkole magii.")
				doPlayerAddItem(cid,2182,1)
			elseif getPlayerVocation(cid) == 3 then
				doPlayerSendTextMessage(cid, 22, "Otrzymales prezent od sklepu 'Dist Tactics'. Pallia zaprasza Ciebie do sklepu dla prawdziwych milosnikow walki z dystansu kiedy tylko bedziesz w Kiobios.")
				doPlayerAddItem(cid,2389,10)
			elseif getPlayerVocation(cid) == 4 then
				doPlayerSendTextMessage(cid, 22, "Otrzymales prezent od Krola Kiobios. Liczy on, ze kiedy rozwiniesz swoje umiejetnosci w walce mieczem staniesz sie jego wiernym rycerzem.")
				doPlayerAddItem(cid,2412,1)
			end
		end

		local oracleCords = {x=303, y=740, z=7} 
		if newlevel >= 8 and getPlayerTown(cid) == 3 then
			doSendMagicEffect(getPlayerPosition(cid),10)
			doPlayerSetTown(cid,1)
			doTeleportThing(cid,oracleCords,0)
			doSendMagicEffect(oracleCords,10)
			doPlayerSendTextMessage(cid, 22, "Gratuluje! Osiagnales poziom na ktorym mozesz juz mieszkac w miescie Kiobios!")
		end

		if newlevel == 13 then
			if isSorcerer(cid) == TRUE then
			doPlayerSendTextMessage(cid, 22, "Magowie dostrzegli, ze bardzo dobrze rozwijasz sie w swojej profesji, aby ulatwic Ci dalszy rozwoj przekazali Ci nowa rozdzke.")
			doPlayerAddItem(cid,2191,1)
			elseif isDruid(cid) == TRUE then
			doPlayerSendTextMessage(cid, 22, "Druidzi przekazali Ci drobny prezent dzieki ktoremu lepiej bedziesz mogl wykorzystac swoja magiczna moc.")
			doPlayerAddItem(cid,2186,1)
			end
		end
		
			if newlevel == 100 then
			local ppos = getPlayerPosition(cid)
			local positions = {
				{x=ppos.x-3, y=ppos.y-1, z=ppos.z},
				{x=ppos.x-1, y=ppos.y-1, z=ppos.z},
				{x=ppos.x, y=ppos.y-1, z=ppos.z},
				{x=ppos.x+1, y=ppos.y-1, z=ppos.z},
				{x=ppos.x+3, y=ppos.y-1, z=ppos.z},
				{x=ppos.x+4, y=ppos.y-1, z=ppos.z},
				{x=ppos.x+5, y=ppos.y-1, z=ppos.z},
				
				{x=ppos.x-3, y=ppos.y, z=ppos.z},
				{x=ppos.x-1, y=ppos.y, z=ppos.z},
				{x=ppos.x+1, y=ppos.y, z=ppos.z},
				{x=ppos.x+3, y=ppos.y, z=ppos.z},
				{x=ppos.x+5, y=ppos.y, z=ppos.z},
				
				{x=ppos.x-3, y=ppos.y+1, z=ppos.z},
				{x=ppos.x-1, y=ppos.y+1, z=ppos.z},
				{x=ppos.x, y=ppos.y+1, z=ppos.z},
				{x=ppos.x+1, y=ppos.y+1, z=ppos.z},
				{x=ppos.x+3, y=ppos.y+1, z=ppos.z},
				{x=ppos.x+4, y=ppos.y+1, z=ppos.z},
				{x=ppos.x+5, y=ppos.y+1, z=ppos.z},
			}
			local effect = math.random(CONST_ME_FIREWORK_YELLOW,CONST_ME_FIREWORK_BLUE)
			for i = 1, table.getn(positions) do
				doSendMagicEffect(positions[i],effect)
			end
		end
	end
	return TRUE
end

function onAdvanceController(cid)
	local skillLevel = OLD_LEVELS[cid]
	local level = getPlayerLevel(cid)
	if skillLevel < level then
		onAdvance(cid, 8, skillLevel, level)
		OLD_LEVELS[cid] = level
	end
	return TRUE
end
function onThink(cid)
	local current_time = os.time()
	if getPlayerStorageValue(cid,STORAGEVALUE_NEXT_REGEN_CHECK) < current_time then
		if OLD_LEVELS[cid] == nil or mshield[cid] == nil then
			OLD_LEVELS[cid] = getPlayerLevel(cid)
			mshield[cid] = 0
		end
		setPlayerStorageValue(cid,STORAGEVALUE_NEXT_REGEN_CHECK, current_time)
		-- SALE TRENINGOWE
		if getPlayerStorageValue(cid, trainstoragevalue_room) > 0 then
			if getPlayerStorageValue(cid, trainstoragevalue_time) < os.time() then --kickowac
				local roomKickPoss = kick_position[getPlayerStorageValue(cid, trainstoragevalue_room)]
				local kickPos = roomKickPoss[math.random(1,6)]
				doTeleportThing(cid, kickPos, TRUE)
				doPlayerSendTextMessage(cid,19,'You were kicked from train room.')
			end
		end
		-- WIEZIENIE
		if getPlayerStorageValue(cid, jailedstoragevalue_bool) == 1 then
			if getPlayerStorageValue(cid, jailedstoragevalue_time) < os.time() then --unjail
				doTeleportThing(cid, unjailpos, TRUE)
				doPlayerSendTextMessage (cid, MESSAGE_INFO_DESCR, 'See you later.')
				setPlayerStorageValue(cid, jailedstoragevalue_time, 0)
				setPlayerStorageValue(cid, jailedstoragevalue_bool, 0)
			else -- czy w wiezieniu powinien byc
				local ppos = getCreaturePosition(cid)
				if ppos.x < jailfrompos.x or ppos.y < jailfrompos.y or ppos.x > jailtopos.x or ppos.y > jailtopos.y then
					doTeleportThing(cid, jailpos, TRUE)
					doPlayerSendTextMessage(cid, MESSAGE_INFO_DESCR, 'You are jailed until ' .. os.date("%H:%M:%S", getPlayerStorageValue(cid, jailedstoragevalue_time)) .. ' (now is: ' .. os.date("%H:%M:%S", os.time()) .. ').')
				end
			end
		end
		-- MANA SHIELD
		local con = math.ceil(getCreatureCondition(cid, CONDITION_MANASHIELD) / 1000)-3
		if con > 0 and con <= 10 and mshield[cid] ~= con then
			mshield[cid] = con
			doPlayerSendTextMessage(cid, MESSAGE_STATUS_CONSOLE_BLUE, "Mana shield konczy sie za pare sekund!")
		end
		onAdvanceController(cid)
	end
 	return TRUE
end
